diff -pruN 2.20.17-1/.github/workflows/python.yml 2.20.19-1/.github/workflows/python.yml
--- 2.20.17-1/.github/workflows/python.yml	2024-02-17 00:42:15.000000000 +0000
+++ 2.20.19-1/.github/workflows/python.yml	2024-03-12 00:32:28.000000000 +0000
@@ -247,11 +247,11 @@ jobs:
           mkdir dist
           mv artifacts/*/* dist/
       - name: Upload to GitHub Release
-        uses: softprops/action-gh-release@v0.1.15
+        uses: softprops/action-gh-release@v2.0.3
         with:
           files: bindings/py/dist/*
       - name: Publish to PyPI
-        uses: pypa/gh-action-pypi-publish@2f6f737ca5f74c637829c0f5c3acd0e29ea5e8bf
+        uses: pypa/gh-action-pypi-publish@81e9d935c883d0b210363ab89cf05f3894778450
         with:
           user: __token__
           password: ${{ secrets.PYPI_API_TOKEN }}
diff -pruN 2.20.17-1/README.md 2.20.19-1/README.md
--- 2.20.17-1/README.md	2024-02-17 00:42:15.000000000 +0000
+++ 2.20.19-1/README.md	2024-03-12 00:32:28.000000000 +0000
@@ -14,7 +14,7 @@
 
 *Did you know that the shortest valid piece of HTML5 is `<!doctype html><title>x</title>`? See for yourself at the [W3C Validator](http://validator.w3.org/)!*
 
-Minify is a minifier package written in [Go][1]. It provides HTML5, CSS3, JS, JSON, SVG and XML minifiers and an interface to implement any other minifier. Minification is the process of removing bytes from a file (such as whitespace) without changing its output and therefore shrinking its size and speeding up transmission over the internet and possibly parsing. The implemented minifiers are designed for high performance.
+Minify is a minifier package written in [Go][1]. It provides HTML5, CSS3, JS, JSON, SVG and XML minifiers and an interface to implement any other minifier. Minification is the process of removing bytes from a file (such as whitespace) without changing its output and therefore shrinking its size and speeding up transmission over the internet and possibly parsing. The implemented minifiers are designed for high performance (see https://github.com/privatenumber/minification-benchmarks where this library is (one of) the fastest JS minifiers).
 
 The core functionality associates mimetypes with minification functions, allowing embedded resources (like CSS or JS within HTML files) to be minified as well. Users can add new implementations that are triggered based on a mimetype (or pattern), or redirect to an external command (like ClosureCompiler, UglifyCSS, ...).
 
diff -pruN 2.20.17-1/cmd/minify/main.go 2.20.19-1/cmd/minify/main.go
--- 2.20.17-1/cmd/minify/main.go	2024-02-17 00:42:15.000000000 +0000
+++ 2.20.19-1/cmd/minify/main.go	2024-03-12 00:32:28.000000000 +0000
@@ -543,12 +543,13 @@ func run() int {
 			defer watcher.Close()
 			changes := watcher.Run()
 
-			for _, filename := range inputs {
-				watcher.AddPath(filename)
-			}
-
+			taskMap := map[string]*Task{}
 			for _, task := range tasks {
-				watcher.IgnoreNext(task.dst)
+				for _, src := range task.srcs {
+					taskMap[src] = &task
+					watcher.AddPath(src)
+				}
+				watcher.IgnoreNext(task.dst) // skip change on output
 				chanTasks <- task
 			}
 
@@ -563,29 +564,16 @@ func run() int {
 						changes = nil
 						break
 					}
-					file = filepath.Clean(file)
 
-					// find longest common path among roots
-					root := ""
-					for _, path := range roots {
-						pathRel, err1 := filepath.Rel(path, file)
-						rootRel, err2 := filepath.Rel(root, file)
-						if err2 != nil || err1 == nil && len(pathRel) < len(rootRel) {
-							root = path
-						}
-					}
-
-					task, err := NewTask(root, file, output, !fileMatches(file))
-					if err != nil {
-						Error.Println(err)
-						return 1
+					task, ok := taskMap[filepath.Clean(file)]
+					if !ok {
+						continue
 					}
 					watcher.IgnoreNext(task.dst) // skip change on output
-					chanTasks <- task
+					chanTasks <- *task
 				}
 			}
 		}
-
 		close(chanTasks)
 		for n := 0; n < numWorkers; n++ {
 			fails += <-chanFails
@@ -698,7 +686,7 @@ func createTasks(fsys fs.FS, inputs []st
 		} else if info.Mode().IsRegular() {
 			valid := fileFilter(input) // don't filter mimetype
 			if valid || sync {
-				if !sync {
+				if mimetype == "" && !sync {
 					ext := filepath.Ext(input)
 					if 0 < len(ext) {
 						ext = ext[1:]
@@ -818,8 +806,9 @@ func minify(t Task) bool {
 		}
 	}
 
-	srcName := strings.Join(t.srcs, " + ")
-	if len(t.srcs) > 1 {
+	srcs := append([]string{}, t.srcs...)
+	srcName := strings.Join(srcs, " + ")
+	if len(srcs) > 1 {
 		srcName = "(" + srcName + ")"
 	}
 	if srcName == "" {
@@ -830,11 +819,11 @@ func minify(t Task) bool {
 		dstName = "stdout"
 	} else {
 		// rename original when overwriting
-		for i := range t.srcs {
-			if sameFile, _ := SameFile(t.srcs[i], t.dst); sameFile {
-				t.srcs[i] += ".bak"
+		for i := range srcs {
+			if sameFile, _ := SameFile(srcs[i], t.dst); sameFile {
+				srcs[i] += ".bak"
 				err := try.Do(func(attempt int) (bool, error) {
-					ferr := os.Rename(t.dst, t.srcs[i])
+					ferr := os.Rename(t.dst, srcs[i])
 					return attempt < 5, ferr
 				})
 				if err != nil {
@@ -849,14 +838,14 @@ func minify(t Task) bool {
 	var err error
 	var fr io.ReadCloser
 	var fw io.WriteCloser
-	if len(t.srcs) == 1 {
-		fr, err = openInputFile(t.srcs[0])
+	if len(srcs) == 1 {
+		fr, err = openInputFile(srcs[0])
 	} else {
 		var sep []byte
 		if err == nil && fileMimetype == extMap["js"] {
 			sep = []byte(";\n")
 		}
-		fr, err = openInputFiles(t.srcs, sep)
+		fr, err = openInputFiles(srcs, sep)
 	}
 	if err != nil {
 		Error.Println(err)
@@ -879,7 +868,7 @@ func minify(t Task) bool {
 			Error.Println(err)
 			return false
 		}
-		preserveAttributes(t.srcs, t.root, t.dst)
+		preserveAttributes(srcs, t.root, t.dst)
 		Info.Printf("copy %v to %v", srcName, dstName)
 		return true
 	}
@@ -917,7 +906,7 @@ func minify(t Task) bool {
 			ratio = float64(wLen) / float64(rLen)
 		}
 
-		stats := fmt.Sprintf("(%6v, %6v, %6v, %5.1f%%, %6v/s)", formatDuration(dur), formatBytes(uint64(rLen)), formatBytes(uint64(wLen)), ratio*100, speed)
+		stats := fmt.Sprintf("(%6v, %6v, %6v, %5.1f%%, %6v/s)", formatDuration(dur), formatBytes(uint64(rLen)), formatBytes(uint64(wLen)), ratio*100.0, speed)
 		if srcName != dstName {
 			fmt.Printf("%v - %v to %v\n", stats, srcName, dstName)
 		} else {
@@ -926,10 +915,10 @@ func minify(t Task) bool {
 	}
 
 	// remove original that was renamed, when overwriting files
-	for i := range t.srcs {
-		if t.srcs[i] == t.dst+".bak" {
+	for i := range srcs {
+		if srcs[i] == t.dst+".bak" {
 			if err == nil {
-				if err = os.Remove(t.srcs[i]); err != nil {
+				if err = os.Remove(srcs[i]); err != nil {
 					Error.Println(err)
 					return false
 				}
@@ -937,16 +926,16 @@ func minify(t Task) bool {
 				if err = os.Remove(t.dst); err != nil {
 					Error.Println(err)
 					return false
-				} else if err = os.Rename(t.srcs[i], t.dst); err != nil {
+				} else if err = os.Rename(srcs[i], t.dst); err != nil {
 					Error.Println(err)
 					return false
 				}
 			}
-			t.srcs[i] = t.dst
+			srcs[i] = t.dst
 			break
 		}
 	}
-	preserveAttributes(t.srcs, t.root, t.dst)
+	preserveAttributes(srcs, t.root, t.dst)
 	return success
 }
 
diff -pruN 2.20.17-1/css/css.go 2.20.19-1/css/css.go
--- 2.20.17-1/css/css.go	2024-02-17 00:42:15.000000000 +0000
+++ 2.20.19-1/css/css.go	2024-03-12 00:32:28.000000000 +0000
@@ -81,14 +81,21 @@ func (t Token) String() string {
 	if len(t.Args) == 0 {
 		return t.TokenType.String() + "(" + string(t.Data) + ")"
 	}
-	return fmt.Sprint(t.Args)
+
+	sb := strings.Builder{}
+	sb.Write(t.Data)
+	for _, arg := range t.Args {
+		sb.WriteString(arg.String())
+	}
+	sb.WriteByte(')')
+	return sb.String()
 }
 
 // Equal returns true if both tokens are equal.
 func (t Token) Equal(t2 Token) bool {
 	if t.TokenType == t2.TokenType && bytes.Equal(t.Data, t2.Data) && len(t.Args) == len(t2.Args) {
 		for i := 0; i < len(t.Args); i++ {
-			if t.Args[i].TokenType != t2.Args[i].TokenType || !bytes.Equal(t.Args[i].Data, t2.Args[i].Data) {
+			if !t.Args[i].Equal(t2.Args[i]) {
 				return false
 			}
 		}
@@ -405,7 +412,7 @@ func (c *cssMinifier) minifyDeclaration(
 	}
 
 	values = c.minifyTokens(prop, 0, values)
-	if len(values) > 0 {
+	if 0 < len(values) {
 		values = c.minifyProperty(prop, values)
 	}
 	c.writeDeclaration(values, important)
@@ -1127,7 +1134,7 @@ func (c *cssMinifier) minifyProperty(pro
 			} else {
 				values[i] = minifyColor(values[i])
 			}
-			if 0 < i && sameValues && !bytes.Equal(values[0].Data, values[i].Data) {
+			if 0 < i && sameValues && !values[0].Equal(values[i]) {
 				sameValues = false
 			}
 		}
diff -pruN 2.20.17-1/css/css_test.go 2.20.19-1/css/css_test.go
--- 2.20.17-1/css/css_test.go	2024-02-17 00:42:15.000000000 +0000
+++ 2.20.19-1/css/css_test.go	2024-03-12 00:32:28.000000000 +0000
@@ -75,7 +75,9 @@ func TestCSS(t *testing.T) {
 		{"@import url(  )", `@import ""`},
 
 		// bugs
-		{"a{@media screen and (min-width:1024px){ width: 40%; } & h1 { font-size: clamp(2.5rem, 1rem + 3vw, 3.5rem)}}", "a{@media screen and (min-width:1024px){width: 40%;}& h1 { font-size: clamp(2.5rem, 1rem + 3vw, 3.5rem)}}"}, // #602
+		{"a{@media screen and (min-width:1024px){ width: 40%; } & h1 { font-size: clamp(2.5rem, 1rem + 3vw, 3.5rem)}}", "a{@media screen and (min-width:1024px){width: 40%;}& h1 { font-size: clamp(2.5rem, 1rem + 3vw, 3.5rem)}}"},      // #602
+		{"a{padding:calc(var(--dce-edge-xsmall,6px) - 2px) calc(var(--dce-button-horizontal-padding,18px) - 2px)}", "a{padding:calc(var(--dce-edge-xsmall,6px) - 2px)calc(var(--dce-button-horizontal-padding,18px) - 2px)}"},            // #673
+		{"a{border-color:var(--dce-brand-color,#01A982)var(--dce-brand-color,#01A982)var(--dce-border-weak,#0000001F)}", "a{border-color:var(--dce-brand-color,#01A982)var(--dce-brand-color,#01A982)var(--dce-border-weak,#0000001F)}"}, // #673
 	}
 
 	m := minify.New()
@@ -90,7 +92,7 @@ func TestCSS(t *testing.T) {
 
 	// coverage
 	test.T(t, Token{css.IdentToken, []byte("data"), nil, 0, 0}.String(), "Ident(data)")
-	test.T(t, Token{css.FunctionToken, nil, []Token{{css.IdentToken, []byte("data"), nil, 0, 0}}, 0, 0}.String(), "[Ident(data)]")
+	test.T(t, Token{css.FunctionToken, []byte("func("), []Token{{css.IdentToken, []byte("data"), nil, 0, 0}}, 0, 0}.String(), "func(Ident(data))")
 }
 
 func TestCSSInline(t *testing.T) {
diff -pruN 2.20.17-1/debian/changelog 2.20.19-1/debian/changelog
--- 2.20.17-1/debian/changelog	2024-02-24 02:01:32.000000000 +0000
+++ 2.20.19-1/debian/changelog	2024-03-25 02:45:07.000000000 +0000
@@ -1,3 +1,9 @@
+golang-github-tdewolff-minify (2.20.19-1) unstable; urgency=medium
+
+  * New upstream version 2.20.19
+
+ -- Anthony Fok <foka@debian.org>  Sun, 24 Mar 2024 20:45:07 -0600
+
 golang-github-tdewolff-minify (2.20.17-1) unstable; urgency=medium
 
   * New upstream version 2.20.17
diff -pruN 2.20.17-1/js/js_test.go 2.20.19-1/js/js_test.go
--- 2.20.17-1/js/js_test.go	2024-02-17 00:42:15.000000000 +0000
+++ 2.20.19-1/js/js_test.go	2024-03-12 00:32:28.000000000 +0000
@@ -179,6 +179,7 @@ func TestJS(t *testing.T) {
 		{`"a"+"b"+5+"c"+"d"`, `"ab"+5+"cd"`},
 		{`"a"+"b"+5+6+"d"`, `"ab"+5+6+"d"`},
 		{"`$${foo}`", "`$${foo}`"},
+		{"'\\n\\nCheck the render method of `'", "`\n\nCheck the render method of \\``"},
 
 		// rename true, false, undefined, Infinity
 		{`x=true`, `x=!0`},
@@ -711,6 +712,7 @@ func TestJS(t *testing.T) {
 		{`a=5;with(b=4){}`, `with(a=5,b=4);`},
 		{`(function(){})();(function(){})()`, `(function(){})(),function(){}()`},
 		//{`for(var a=0;;){var b=5;var d=6;for(var c=0;;);}`, `for(a=0;;)for(var a,b=5,d=6,c=0;;);`}, // TODO
+		//{`var aaaa=[];for(var b=0;;){}for(var b in aaaa){}var aaaa=[];for(var b=0;;){}`, `for(var aaaa=[],b=0;;);for(b in aaaa);for(aaaa=[],b=0;;);`}, // TODO
 
 		// collapse functions
 		//{`var a=function(){return 5}`, `var a=()=>5`},
@@ -808,8 +810,8 @@ func TestJS(t *testing.T) {
 		{`export default function Foo(){a}Foo.prototype.bar=b`, `export default function Foo(){a}Foo.prototype.bar=b`},                                     // #525
 		{`(e=1,e=2)`, `e=1,e=2`},                  // #528
 		{`"\x00\x31 \0\u0000"`, `"\x001 \0\x00"`}, // #577
-		{`function transform(){{var aaaa=[];for(var b=0;;){}for(var b in aaaa){}var aaaa=[];for(var b=0;;){}}}`, `function transform(){{for(var aaaa=[],b=0;;);for(b in aaaa);for(aaaa=[],b=0;;);}}`}, // #619
-		{`for(var a=0;;){var b=5;for(var c=0;;);}`, `for(var b,c,a=0;;)for(b=5,c=0;;);`},                                                                                                              // #634
+		{`function transform(){{var aaaa=[];for(var b=0;;){}for(var b in aaaa){}var aaaa=[];for(var b=0;;){}}}`, `function transform(){{for(var aaaa=[],b=0;;);for(b in aaaa);for(var aaaa=[],b=0;;);}}`}, // #619
+		{`for(var a=0;;){var b=5;for(var c=0;;);}`, `for(var b,c,a=0;;)for(b=5,c=0;;);`},                                                                                                                  // #634
 		{"if(a)for(;;)\n;else b", `if(a)for(;;);else b`},       // #636
 		{`'\u000A\u000D'`, "`\n\r`"},                           // #653
 		{`for(!a;b;c);`, "for(!a;b;c);"},                       // #656
diff -pruN 2.20.17-1/js/util.go 2.20.19-1/js/util.go
--- 2.20.17-1/js/util.go	2024-02-17 00:42:15.000000000 +0000
+++ 2.20.19-1/js/util.go	2024-03-12 00:32:28.000000000 +0000
@@ -1023,7 +1023,7 @@ func replaceEscapes(b []byte, quote byte
 	// strip unnecessary escapes
 	j := 0
 	start := 0
-	for i := prefix; i < len(b)-suffix-1; i++ {
+	for i := prefix; i < len(b)-suffix; i++ {
 		if c := b[i]; c == '\\' {
 			c = b[i+1]
 			if c == quote || c == '\\' || quote != '`' && (c == 'n' || c == 'r') || c == '0' && (len(b)-suffix <= i+2 || b[i+2] < '0' || '7' < b[i+2]) {
diff -pruN 2.20.17-1/js/vars.go 2.20.19-1/js/vars.go
--- 2.20.17-1/js/vars.go	2024-02-17 00:42:15.000000000 +0000
+++ 2.20.19-1/js/vars.go	2024-03-12 00:32:28.000000000 +0000
@@ -288,112 +288,90 @@ func mergeVarDeclExprStmt(decl *js.VarDe
 	return false
 }
 
-func (m *jsMinifier) varNameLen(v *js.Var) int {
+func (m *jsMinifier) countHoistLength(ibinding js.IBinding) int {
 	if !m.o.KeepVarNames {
-		return 2 // assume that var name will be of length one, +1 for the comma
+		return len(bindingVars(ibinding)) * 2 // assume that var name will be of length one, +1 for the comma
 	}
-	return len(v.Data) + 1 // +1 for the comma when added to other declaration
+
+	n := 0
+	for _, v := range bindingVars(ibinding) {
+		n += len(v.Data) + 1 // +1 for the comma when added to other declaration
+	}
+	return n
 }
 
 func (m *jsMinifier) hoistVars(body *js.BlockStmt) {
-	// Hoist all variable declarations in the current module/function scope to the top
-	// Find the best var declaration (that results in the shortest code), all others are converted to expressions.
-	// This is possible because an ArrayBindingPattern and ObjectBindingPattern can be converted to an ArrayLiteral or ObjectLiteral respectively, as they are supersets of the BindingPatterns.
+	// Hoist all variable declarations in the current module/function scope to the variable
+	// declaration that reduces file size the most. All other declarations are converted to
+	// expressions and their variable names are copied to the only remaining declaration.
+	// This is possible because an ArrayBindingPattern and ObjectBindingPattern can be converted to
+	// an ArrayLiteral or ObjectLiteral respectively, as they are supersets of the BindingPatterns.
 	if 1 < len(body.Scope.VarDecls) {
 		// Select which variable declarations will be hoisted (convert to expression) and which not
 		best := 0
 		scores := make([]int, len(body.Scope.VarDecls)) // savings if hoisting target
-		hoists := make([][]bool, len(body.Scope.VarDecls))
-		for i, target := range body.Scope.VarDecls {
-			// keep list of target variables to avoid declaring a var more than once
-			var refsTarget []*js.Var
-			for _, item := range target.List {
-				refsTarget = append(refsTarget, bindingVars(item.Binding)...)
+		hoist := make([]bool, len(body.Scope.VarDecls))
+		for i, varDecl := range body.Scope.VarDecls {
+			hoist[i] = true
+			if varDecl.InForInOf {
+				continue
 			}
 
-			hoists[i] = make([]bool, len(body.Scope.VarDecls))
-			for j, varDecl := range body.Scope.VarDecls {
-				if i == j {
-					hoists[i][j] = false
-					continue
-				}
-
-				score := 4 // "var "
-				hoists[i][j] = true
-				if !varDecl.InForInOf {
-					// variable names in for-in or for-of cannot be removed
-					n := 0        // total number of vars with decls
-					nArrays := 0  // of which lhs arrays
-					nObjects := 0 // of which lhs objects
-					nNames := 0   // length of var names and commas
-					hasDefinitions := false
-					for k, item := range varDecl.List {
-						if item.Default != nil {
-							// move arrays/objects to the front (saves a space)
-							if _, ok := item.Binding.(*js.BindingObject); ok {
-								if k != 0 && nArrays == 0 && nObjects == 0 {
-									varDecl.List[0], varDecl.List[k] = varDecl.List[k], varDecl.List[0]
-								}
-								nObjects++
-							} else if _, ok := item.Binding.(*js.BindingArray); ok {
-								if k != 0 && nArrays == 0 && nObjects == 0 {
-									varDecl.List[0], varDecl.List[k] = varDecl.List[k], varDecl.List[0]
-								}
-								nArrays++
-							}
-
-							refs := bindingVars(item.Binding)
-						CountNamesLoop:
-							for _, ref := range refs {
-								for _, v := range refsTarget {
-									if ref == v {
-										// already exists in target
-										continue CountNamesLoop
-									}
-								}
-
-								// declaration separate from assignment will copy var name + comma
-								nNames += m.varNameLen(ref)
-								refsTarget = append(refsTarget, ref)
-							}
-							hasDefinitions = true
-							n++
+			// variable names in for-in or for-of cannot be removed
+			n := 0        // total number of vars with decls
+			score := 3    // "var"
+			nArrays := 0  // of which lhs arrays
+			nObjects := 0 // of which lhs objects
+			hasDefinitions := false
+			for j, item := range varDecl.List {
+				if item.Default != nil {
+					// move arrays/objects to the front (saves a space)
+					if _, ok := item.Binding.(*js.BindingObject); ok {
+						if j != 0 && nArrays == 0 && nObjects == 0 {
+							varDecl.List[0], varDecl.List[j] = varDecl.List[j], varDecl.List[0]
 						}
+						nObjects++
+					} else if _, ok := item.Binding.(*js.BindingArray); ok {
+						if j != 0 && nArrays == 0 && nObjects == 0 {
+							varDecl.List[0], varDecl.List[j] = varDecl.List[j], varDecl.List[0]
+						}
+						nArrays++
 					}
-					if hasDefinitions {
-						score -= nNames // copy var names and commas to target
-					} else if varDecl.InFor {
-						score-- // semicolon can be reused
-					}
-					if nObjects != 0 && !varDecl.InFor && nObjects == n {
-						score -= 2 // required parenthesis around braces
-					}
-					if nArrays != 0 || nObjects != 0 {
-						score-- // space after var disappears
-					}
-					if score < 0 {
-						// don't hoist if it increases the amount of characters
-						hoists[i][j] = false
-						score = 0
-					}
+					score -= m.countHoistLength(item.Binding) // var names and commas
+					hasDefinitions = true
+					n++
 				}
-				scores[i] += score
 			}
-			if scores[best] < scores[i] || body.Scope.VarDecls[best].InForInOf {
-				// select var decl with the most savings if hoist target
+			if nArrays == 0 && nObjects == 0 {
+				score++ // required space after var
+			}
+			if !hasDefinitions && varDecl.InFor {
+				score-- // semicolon can be reused
+			}
+			if nObjects != 0 && !varDecl.InFor && nObjects == n {
+				// required parenthesis around braces to not confound it with a block statement
+				score -= 2
+			}
+			if score < scores[best] || body.Scope.VarDecls[best].InForInOf {
+				// select var decl that reduces the least when hoist target
 				best = i
 			}
+			if score < 0 {
+				// don't hoist if it increases the amount of characters
+				hoist[i] = false
+			}
+			scores[i] = score
 		}
-		if scores[best] < 0 || body.Scope.VarDecls[best].InForInOf {
+		if body.Scope.VarDecls[best].InForInOf {
 			// no savings possible
 			return
 		}
 
-		hoist := hoists[best]
 		decl := body.Scope.VarDecls[best]
 		if 10000 < len(decl.List) {
 			return
 		}
+		hoist[best] = false
 
 		// get original declarations
 		orig := []*js.Var{}
